@@ -23,3 +23,8 @@ class Element:
 
     def flag_lists(self):
         return self._client._flag_lists_manager.flag_lists(self.url + "/flags")
+
+    def add_flag(self, name):
+        current_flag_list_names = [flag.code for flag in self.flag_lists()]
+
+        
